@@ -182,9 +182,9 @@ gsf_input_memory_class_init (GObjectClass *gobject_class)
 	parent_class = g_type_class_peek_parent (gobject_class);
 }
 
-GSF_DYNAMIC_CLASS (GsfInputMemory, gsf_input_memory,
-		   gsf_input_memory_class_init, gsf_input_memory_init,
-		   GSF_INPUT_TYPE)
+GSF_CLASS (GsfInputMemory, gsf_input_memory,
+	   gsf_input_memory_class_init, gsf_input_memory_init,
+	   GSF_INPUT_TYPE)
 
 /***************************************************************************/
 
