@@ -2,7 +2,7 @@
 /*
  * gsf-input-stdio.c: stdio based input
  *
- * Copyright (C) 2002-2004 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2006 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2.1 of the GNU Lesser General Public
@@ -274,4 +274,6 @@ gsf_input_stdio_class_init (GObjectClass *gobject_class)
 }
 
 GSF_CLASS (GsfInputStdio, gsf_input_stdio,
-	   gsf_input_stdio_class_init, gsf_input_stdio_init, GSF_INPUT_TYPE)
+	   gsf_input_stdio_class_init, gsf_input_stdio_init,
+	   GSF_INPUT_TYPE)
+
